@@ -1,19 +1,47 @@
 setClass("moduleWeb", representation(originalWeb="matrix", moduleWeb="matrix", orderA="vector", orderB="vector", modules="matrix", likelihood="numeric"));
 
-computeModules = function(web, deep = FALSE, deleteOriginalFiles=TRUE, steps=1000000) {
+computeModules = function(web, deep=FALSE, deleteOriginalFiles=TRUE, steps=1000000, tolerance=1e-10, experimental=FALSE) {
 
-	result		= cM(web, depth=1, nrOfModule=1, ytop=1, xleft=1, ybottom=dim(web)[1], 
-					  xright=dim(web)[2], prev_orderA=c(1:dim(web)[1]), prev_orderB=c(1:dim(web)[2]), 
-					  modules=matrix(c(0, 1, c(1:sum(dim(web)))), 1), 
-					  deepCompute=deep, delete=deleteOriginalFiles, steps=steps);
-	result[[4]]	= result[[4]][order(result[[4]][,1]),];
+	if(deep && experimental) {
+		print("ERROR: Flag deep has to be FALSE if flag experimental is set to TRUE.");
+		NULL;
+	}
+	else {
 
-	new("moduleWeb", originalWeb=web, moduleWeb=result[[1]], orderA=result[[2]], orderB=result[[3]], modules=result[[4]], likelihood=result[[5]]);
+		web <- as.matrix(empty(web, count=TRUE)) # to get rid of empty columns and rows
+		if (any(attr(web, "empty")) > 0) warning("Some empty columns or rows were deleted.")
+		
+		cat("This function is SLOW! \nMonitor your system's activity; depending on steps-setting this may take minutes to hours!\n\n")
+		
+		result		<-  cM(web, depth=1, nrOfModule=1, ytop=1, xleft=1, ybottom=dim(web)[1], 
+						  xright=dim(web)[2], prev_orderA=c(1:dim(web)[1]), prev_orderB=c(1:dim(web)[2]), 
+						  modules=matrix(c(0, 1, c(1:sum(dim(web)))), 1), 
+						  deepCompute=deep, delete=deleteOriginalFiles, steps=steps, tolerance=tolerance, experimental=experimental) #try()
+	#	if (inherits(result, "try-error")) {
+	#		print(result)
+	#		break;
+	#	}
+		result[[4]]	= result[[4]][order(result[[4]][,1]),];
+
+		# Make sure the modularity is non-negative
+		if(result[[5]] >= 0) {
+			new("moduleWeb", originalWeb=web, moduleWeb=as.matrix(result[[1]]), orderA=result[[2]], orderB=result[[3]], modules=result[[4]], likelihood=result[[5]]);
+		}
+		else {
+			if(deep) {
+				print("ERROR: At least one of the computed modularity values is smaller than 0. Please increase the number of steps in order to reach a valid result.");
+			}
+			else {
+				print("ERROR: The computed modularity value is smaller than 0. Please increase the number of steps in order to reach a valid result.");
+			}
+			NULL;
+		}
+	}
 }
 
 
 # This function actually prepares the recursive computation of the modules and returns an object of class "moduleWeb"
-cM = function(web, depth, nrOfModule, ytop, xleft, ybottom, xright, prev_orderA, prev_orderB, modules, deepCompute, delete, steps) {
+cM = function(web, depth, nrOfModule, ytop, xleft, ybottom, xright, prev_orderA, prev_orderB, modules, deepCompute, delete, steps, tolerance, experimental) {
 
 	result = list();
 
@@ -21,7 +49,10 @@ cM = function(web, depth, nrOfModule, ytop, xleft, ybottom, xright, prev_orderA,
 
 	# write web to file
 	web2edges(web[ytop:ybottom, xleft:xright], webName=webName);
-	argv = c("identifyModules", "-filename", paste(webName, ".pairs", sep=""), "-bipartite", "-steps", as.integer(steps));
+	argv = c("identifyModules", "-filename", paste(webName, ".pairs", sep=""), "-steps", as.integer(steps), "-tolerance", as.double(tolerance));
+	if(experimental) {
+		argv = append(argv, c("-method", "Strauss"));
+	}
 	argv = as.character(argv);
 	argc = as.integer(length(argv));
 
@@ -34,7 +65,7 @@ cM = function(web, depth, nrOfModule, ytop, xleft, ybottom, xright, prev_orderA,
 	dyn.load(IMpath)
 	
 	# read in data from result files
-	data = readModuleData(webName, deleteOriginalFiles=delete);
+	data = readModuleData(webName, deleteOriginalFiles=delete); #delete.edgesOriginalFiles=delete);
 
 	n_a		= dim(web)[1];
 	n_b		= dim(web)[2];
@@ -43,50 +74,91 @@ cM = function(web, depth, nrOfModule, ytop, xleft, ybottom, xright, prev_orderA,
 	orderAFile	= data[[1]];
 	orderBFile	= data[[2]];
 	modulesFile	= data[[3]];
-	infoFile	= data[[4]];
-
+	likelihood	= as.numeric(data[[4]]);
+	
 	# Permutation of the graph and therefore actualization of the permutation vectors is necessary
 	# if more than one module are suggested
-	if(nrow(modulesFile) > 1) {
+	if (likelihood >= 0 && nrow(modulesFile) > 1) {
 
 		# Actualization of the permutation vectors
-		tempA			= c(1:dim(web)[1]);
-		tempB			= c(1:dim(web)[2]);
+		tempA				= c(1:dim(web)[1]);
+		tempB				= c(1:dim(web)[2]);
 		tempA[ytop:ybottom]	= tempA[ytop:ybottom][orderAFile];
 		tempB[xleft:xright]	= tempB[xleft:xright][orderBFile-length(orderAFile)];
-		orderAFile		= prev_orderA[tempA];
-		orderBFile		= prev_orderB[tempB];
+		orderAFile			= prev_orderA[tempA];
+		orderBFile			= prev_orderB[tempB];
 
-		result[[1]] = web[tempA, tempB];
+		result[[1]] = as.matrix(web[tempA, tempB, drop=FALSE])
 		result[[2]] = orderAFile;
 		result[[3]] = orderBFile;
-		result[[4]] <- NA
-		result[[5]] = as.numeric(infoFile); # likelihood
-
+		result[[4]] = NA;
+		
 		# The matrix M containing the information about the identified modules is formatted in the following way:
 		# Each row i contains the information about one certain module while
 		# M[i,1] represents the nesting depth of the module,
 		# M[i,2] = 1 iff the module is the last one to plot within its nesting module and 0 else,
-		# and the M[i,j] = j-offset iff node j-offset is part of the module and 0 else.
-		offset_M = 2;
-		offset_modulesFile = 1;
-		nrOfModules = dim(modulesFile)[1];
+		# and the M[i,j] = j-offset_M iff node j-offset_M is part of the module and 0 else.
+		offset_M			= 2;
+		offset_modulesFile	= 1;	
+		nrOfModules			= nrow(modulesFile);
+		M					= matrix(0, nrOfModules, (sum(dim(web))+offset_M));
 
-		M									= matrix(0, nrOfModules, (sum(dim(web))+offset_M));
-		M[, 1]								= depth;
-		M[nrOfModules, 2]						= 1;
-
-		colvals = append(prev_orderA[ytop:ybottom], prev_orderB[xleft:xright]+n_a);
-		rowvals = which(modulesFile[, 2:ncol(modulesFile)] > 0) %% nrow(modulesFile);
-		rowvals[rowvals == 0] = nrow(modulesFile);
-		if(length(colvals) == length(rowvals)) {
-			for(i in 1:length(colvals)) {
-				M[rowvals[i], colvals[i]+offset_M] = colvals[i];
+		if(experimental) {
+		
+			M[,1]	= modulesFile[,1];
+			M[1,2]	= 1;
+		
+			for(i in nrOfModules:1) {
+			
+				if(i > 1) {
+					indicesOfNextRowsWithSameDepth = rev(which(M[1:(i - 1),1] == M[i,1]));
+					
+					if(	length(indicesOfNextRowsWithSameDepth) == 0
+						||
+						(indicesOfNextRowsWithSameDepth[1] + 1 < i && length(which(M[(indicesOfNextRowsWithSameDepth[1] + 1):(i - 1),1] < M[i,1])) > 0)) {
+						M[i,2] = 1;
+					}
+				}
+				
+				M[i, (1 + offset_M):(ncol(modulesFile)+1)] = modulesFile[i, (1 + offset_modulesFile):ncol(modulesFile)];
+			}
+			
+			M_temp		= matrix(0, nrow(M), ncol(M));
+			maxDepth	= max(M[,1]);
+			rowCounter	= 1;
+			
+			for(i in 0:maxDepth) {
+				indicesOfRowsWithSameDepth		= rev(which(M[,1] == i));
+				nrOfIndicesOfRowsWithSameDepth	= length(indicesOfRowsWithSameDepth);
+				M_temp[rowCounter:(rowCounter + nrOfIndicesOfRowsWithSameDepth - 1),] = M[indicesOfRowsWithSameDepth,];
+				rowCounter = rowCounter + nrOfIndicesOfRowsWithSameDepth;
+			}
+			
+			M = M_temp;
+		}
+		else {
+		
+			M[, 1]								= depth;
+			M[nrOfModules, offset_M]			= 1;
+		
+			colvals = append(prev_orderA[ytop:ybottom], prev_orderB[xleft:xright]+n_a);
+			rowvals = which(modulesFile[, offset_M:ncol(modulesFile)] > 0) %% nrow(modulesFile);
+			rowvals[rowvals == 0] = nrow(modulesFile);
+			if(length(colvals) == length(rowvals)) {
+				for(i in 1:length(colvals)) {
+					M[rowvals[i], colvals[i]+offset_M] = colvals[i];
+				}
 			}
 		}
+					
+		modulesFile = M;
 
-		modulesFile	 = M;
-		result[[4]]	 = rbind(modules, M);
+		if(experimental) {
+			result[[4]]	= M;
+		}
+		else {
+			result[[4]]	= rbind(modules, M);
+		}
 
 		# Computation of potential modules nested within the ones found until now
 		if(deepCompute) {
@@ -116,24 +188,31 @@ cM = function(web, depth, nrOfModule, ytop, xleft, ybottom, xright, prev_orderA,
 
 				# An invocation of cM(...) is necessary only if there is the possibility to find more than one submodule the current module consists of
 				if((ybottom_new - ytop_new)+1 > 1 && (xright_new - xleft_new)+1 > 1) {
+
 					print(paste("Recursive invocation (depth: ", depth+1, ", module nr. ", i, ")", sep=""));
+
 					result = cM(web=result[[1]], depth+1, nrOfModule=i, ytop=ytop_new, xleft=xleft_new, 
 								ybottom=ybottom_new, xright=xright_new, prev_orderA=result[[2]], prev_orderB=result[[3]], 
-								modules=result[[4]], deepCompute, delete, steps)
+								modules=result[[4]], deepCompute, delete, steps, tolerance, experimental);
+
+					# Make sure that all computed modules have modularity >= 0
+					if(result[[5]] < 0) {
+						likelihood = result[[5]];
+					}
 				}
 			}
 		}
-
 	}
 	else {
 		result[[1]] = web;
 		result[[2]] = prev_orderA;
 		result[[3]] = prev_orderB;
 		result[[4]] = modules;
-		result[[5]] <- infoFile;
 	}
+	
+	result[[5]] = likelihood;
 
-	result;
+	result
 
 }
 
@@ -143,7 +222,7 @@ readModuleData = function(webName=NULL, deleteOriginalFiles=TRUE) {
 	orderAFile = as.vector(as.matrix(read.table(paste(webName, ".ordA", sep=""), header=TRUE, sep="\t")));
 	orderBFile = as.vector(as.matrix(read.table(paste(webName, ".ordB", sep=""), header=TRUE, sep="\t")));
 	modulesFile = as.matrix(read.table(paste(webName, ".mod", sep=""), header=TRUE, sep="\t"));
-	infoFile = strsplit(readLines(paste(webName, ".info", sep=""), n=-1)[15], ": ")[[1]][2]  # reads in only the likelihood!
+	infoFile = strsplit(readLines(paste(webName, ".info", sep=""), n=-1)[26], ": ")[[1]][2]  # reads in only the likelihood!
 	#read.table(paste(webName, ".info", sep=""), header=TRUE, sep="\t");
 
 	if(deleteOriginalFiles) deleteModuleData(webName);
@@ -168,6 +247,27 @@ deleteModuleData = function(webName=NULL) {
 	unlink(paste(webName, ".info", sep=""));
 }
 
+# This function is ALSO in drawModules.R!!
+# Auxiliary function checking whether the passed object is an object of class "moduleWeb" and contains correctly formatted information
+isCorrectModuleWebObject = function(moduleWebObject) {
+
+	if (!is(moduleWebObject, "moduleWeb")) {
+		warning("Object of wrong class.");
+		FALSE;
+	}
+	else if(dim(slot(moduleWebObject, "originalWeb")) == 0 ||  dim(slot(moduleWebObject, "moduleWeb")) != dim(slot(moduleWebObject, "originalWeb")) || dim(slot(moduleWebObject, "modules")) == 0) {
+		warning("Object corrupt.");
+		FALSE;
+	}
+	else if(min(slot(moduleWebObject, "originalWeb")) < 0 || min(slot(moduleWebObject, "moduleWeb")) < 0) {
+		warning("entries of matrix have to be greater than or equal to 0.");
+		FALSE;
+	}
+	else {
+		TRUE;
+	}
+}
+######----- ########
 
 listModuleInformation = function(moduleWebObject) {
 
